pub struct CreateEmptyTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub location: Option<String>,
pub vend_credentials: Option<bool>,
}Expand description
CreateEmptyTableRequest : Request for creating an empty table. Deprecated: Use DeclareTableRequest instead.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>location: Option<String>Optional storage location for the table. If not provided, the namespace implementation should determine the table location.
vend_credentials: Option<bool>Whether to include vended credentials in the response storage_options. When true, the implementation should provide vended credentials for accessing storage. When not set, the implementation can decide whether to return vended credentials.
Implementations
Sourceimpl CreateEmptyTableRequest
impl CreateEmptyTableRequest
Sourcepub fn new() -> CreateEmptyTableRequest
pub fn new() -> CreateEmptyTableRequest
Request for creating an empty table. Deprecated: Use DeclareTableRequest instead.