pub struct CreateNamespaceRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub mode: Option<String>,
pub properties: Option<HashMap<String, String>>,
}Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>mode: Option<String>There are three modes when trying to create a namespace, to differentiate the behavior when a namespace of the same name already exists. Case insensitive, supports both PascalCase and snake_case. Valid values are: * Create: the operation fails with 409. * ExistOk: the operation succeeds and the existing namespace is kept. * Overwrite: the existing namespace is dropped and a new empty namespace with this name is created.
properties: Option<HashMap<String, String>>Properties stored on the namespace, if supported by the implementation.
Implementations
Sourceimpl CreateNamespaceRequest
impl CreateNamespaceRequest
pub fn new() -> CreateNamespaceRequest