CreateTableBranchRequest

Struct CreateTableBranchRequest 

pub struct CreateTableBranchRequest {
    pub identity: Option<Box<Identity>>,
    pub context: Option<HashMap<String, String>>,
    pub id: Option<Vec<String>>,
    pub name: String,
    pub from_branch: Option<String>,
    pub from_version: Option<i64>,
}

Fields

identity: Option<Box<Identity>>context: Option<HashMap<String, String>>

Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.

id: Option<Vec<String>>name: String

Name of the branch to create

from_branch: Option<String>

Source branch to create the new branch from. When omitted, the new branch is created from the main branch.

from_version: Option<i64>

Version of the source (branch or main) to create from. When omitted, the latest version of the source is used.

Implementations