pub struct InsertIntoTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub mode: Option<String>,
}Expand description
InsertIntoTableRequest : Request for inserting records into a table, excluding the Arrow IPC stream.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>mode: Option<String>How the insert should behave. Case insensitive, supports both PascalCase and snake_case. Valid values are: - Append (default): insert data to the existing table - Overwrite: remove all data in the table and then insert data to it
Implementations
Sourceimpl InsertIntoTableRequest
impl InsertIntoTableRequest
Sourcepub fn new() -> InsertIntoTableRequest
pub fn new() -> InsertIntoTableRequest
Request for inserting records into a table, excluding the Arrow IPC stream.