pub struct CreateTableRequest {
pub identity: Option<Box<Identity>>,
pub context: Option<HashMap<String, String>>,
pub id: Option<Vec<String>>,
pub mode: Option<String>,
}Expand description
CreateTableRequest : Request for creating a table, excluding the Arrow IPC stream.
Fields
identity: Option<Box<Identity>>context: Option<HashMap<String, String>>Arbitrary context for a request as key-value pairs. How to use the context is custom to the specific implementation. REST NAMESPACE ONLY Context entries are passed via HTTP headers using the naming convention x-lance-ctx-<key>: <value>. For example, a context entry {\"trace_id\": \"abc123\"} would be sent as the header x-lance-ctx-trace_id: abc123.
id: Option<Vec<String>>mode: Option<String>There are three modes when trying to create a table, to differentiate the behavior when a table of the same name already exists. Case insensitive, supports both PascalCase and snake_case. Valid values are: * Create: the operation fails with 409. * ExistOk: the operation succeeds and the existing table is kept. * Overwrite: the existing table is dropped and a new table with this name is created.
Implementations
Sourceimpl CreateTableRequest
impl CreateTableRequest
Sourcepub fn new() -> CreateTableRequest
pub fn new() -> CreateTableRequest
Request for creating a table, excluding the Arrow IPC stream.